##
##  portfwd.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2008 OpenPKG Foundation e.V. <http://openpkg.net/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         portfwd
Summary:      TCP/UDP Port Forwarding Daemon
URL:          http://portfwd.sourceforge.net/
Vendor:       Everton da Silva Marques
Packager:     OpenPKG Foundation e.V.
Distribution: OpenPKG Community
Class:        BASE
Group:        Network
License:      GPL
Version:      0.29
Release:      20080101

#   package options
%option       with_fsl yes

#   list of sources
Source0:      http://switch.dl.sourceforge.net/sourceforge/portfwd/portfwd-%{version}.tar.gz
Source1:      portfwd.cfg
Source2:      rc.portfwd
Source3:      fsl.portfwd
Patch0:       portfwd.patch

#   build information
Prefix:       %{l_prefix}
BuildRoot:    %{l_buildroot}
BuildPreReq:  OpenPKG, openpkg >= 20060823, gcc, make, flex
PreReq:       OpenPKG, openpkg >= 20060823
%if "%{with_fsl}" == "yes"
BuildPreReq:  fsl
PreReq:       fsl
%endif
AutoReq:      no
AutoReqProv:  no

%description
    Portfwd is a port forwarding daemon which forwards incoming TCP
    connections and/or UDP datagrams to remote hosts. There is support
    for FTP forwarding, transparent proxy, DNS on demand, simple
    round-robin load-balacing, external destination selectors and other
    minor features.

%track
    prog portfwd = {
        version   = %{version}
        url       = http://prdownloads.sourceforge.net/portfwd/
        regex     = portfwd-(__VER__)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0

    #   patch source tree
    %{l_shtool} subst \
        -e 's;\(AUTOMAKE\)=.*;\1=true;' \
        -e 's;\(AUTOCONF\)=.*;\1=true;' \
        -e 's;\(AUTOHEADER\)=.*;\1=true;' \
        -e 's;\(ACLOCAL\)=.*;\1=true;' \
        -e 's;\(MAKEINFO\)=.*;\1=true;' \
        configure

%build
    #   configure package
    cppflags=""
    case "%{l_platform -t}" in
        *-sunos5.6 ) cppflags="-Dsocklen_t=int" ;;
    esac
    CC="%{l_cc}" \
    CXX="%{l_cxx}" \
    CFLAGS="%{l_cflags -O}" \
    CXXFLAGS="%{l_cxxflags -O}" \
    CPPFLAGS="%{l_cppflags} $cppflags" \
    LDFLAGS="%{l_ldflags} %{l_fsl_ldflags}" \
    LIBS="%{l_fsl_libs}" \
    ./configure \
        --prefix=%{l_prefix} \
        --sysconfdir=%{l_prefix}/etc/portfwd

    #   build package
    %{l_make} %{l_mflags -O}

%install
    rm -rf $RPM_BUILD_ROOT

    #   create installation hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/sbin \
        $RPM_BUILD_ROOT%{l_prefix}/etc/portfwd \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d \
        $RPM_BUILD_ROOT%{l_prefix}/man/man8 \
        $RPM_BUILD_ROOT%{l_prefix}/man/man5 \
        $RPM_BUILD_ROOT%{l_prefix}/var/portfwd

    #   install program and manual page
    %{l_shtool} install -c -s -m 755 \
        src/portfwd $RPM_BUILD_ROOT%{l_prefix}/sbin/
    %{l_shtool} install -c -m 644 \
        doc/portfwd.8 $RPM_BUILD_ROOT%{l_prefix}/man/man8/
    %{l_shtool} install -c -m 644 \
        -e 's;conf\.txt;portfwd.txt;g' \
        doc/portfwd.cfg.5 $RPM_BUILD_ROOT%{l_prefix}/man/man5/

    #   install default configuration and configuration grammar summary
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE portfwd.cfg} $RPM_BUILD_ROOT%{l_prefix}/etc/portfwd/
    %{l_shtool} install -c -m 644 \
        doc/conf.txt $RPM_BUILD_ROOT%{l_prefix}/etc/portfwd/portfwd.txt

    #   install run-command script
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.portfwd} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   install OSSP fsl configuration
    %{l_shtool} mkdir -f -p -m 755 $RPM_BUILD_ROOT%{l_prefix}/etc/fsl
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE fsl.portfwd} $RPM_BUILD_ROOT%{l_prefix}/etc/fsl/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/fsl/fsl.portfwd' \
        '%config %{l_prefix}/etc/portfwd/portfwd.cfg'

%files -f files

%clean
    rm -rf $RPM_BUILD_ROOT

%pre
    #   before upgrade, save status and stop service
    [ $1 -eq 2 ] || exit 0
    eval `%{l_rc} portfwd status 2>/dev/null | tee %{l_tmpfile}`
    %{l_rc} portfwd stop 2>/dev/null
    exit 0

%post
    if [ $1 -eq 2 ]; then
        #   after upgrade, restore status
        eval `cat %{l_tmpfile}`; rm -f %{l_tmpfile}
        [ ".$portfwd_active" = .yes ] && %{l_rc} portfwd start
    fi
    exit 0

%preun
    #   before erase, stop service and remove log files
    [ $1 -eq 0 ] || exit 0
    %{l_rc} portfwd stop 2>/dev/null
    rm -f $RPM_INSTALL_PREFIX/var/portfwd/*.log* >/dev/null 2>&1 || true
    exit 0

